import { Award, BarChart2, Code, LayoutDashboard, Settings2, type LucideIcon } from 'lucide-react';

/**
 * A navigation item.
 *
 * @typedef {Object} NavItem
 *
 * @property {string} name - The name of the navigation item.
 * @property {string} slug - The slug of the navigation item.
 * @property {boolean} [disabled] - Whether the navigation item is disabled.
 */
export type NavItem = {
  name: string;
  slug: string;
  icon: LucideIcon | React.JSXElementConstructor<React.SVGProps<SVGSVGElement>>;
  disabled?: boolean;
};

/**
 * Navigation items.
 *
 * @type {NavItem[]}
 */
export const navItems: NavItem[] = [
  {
    name: 'Dashboard',
    slug: 'dashboard',
    icon: LayoutDashboard,
    disabled: false
  },
  {
    name: 'Classement',
    slug: 'dashboard/leaderboard',
    icon: BarChart2,
    disabled: false
  },
  {
    name: 'Puzzles',
    slug: 'dashboard/puzzles',
    icon: Code,
    disabled: false
  },
  {
    name: 'Badges',
    slug: 'dashboard/badges',
    icon: Award,
    disabled: false
  },
  {
    name: 'Paramètres',
    slug: 'dashboard/settings',
    icon: Settings2,
    disabled: false
  }
];
